=begin
(c) TIG 2010
Permission to use, copy, modify, and distribute this software for 
any purpose and without fee is hereby granted, provided that the above
copyright notice appear in all copies.
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
___________________________________________________________________________

  exportlayers2daes.rb >>> ../Plugins/ folder
___________________________________________________________________________
Purpose:
It exports everything in the Model's entities on each 'Layer' as a separate 
Collada '.dae' file.
___________________________________________________________________________
Usage:
To run the tool type 'exportlayers2daes' in the Ruby Console.
If the Model SKP is new and has not yet been saved you will get an error.
Layers are NOT exported if they are switched 'off'.
Layers are NOT exported if they do not contain 'entities'.
All eligible Layers are processed in turn.
The DAE file path in displayed in the Console.
The DAE files are exported into the Model's folder.
They are named after the Layer.
'Layer0.dae'
'Furniture.dae'
'Site.dae'
The 'file_name' is based on the 'layer_name' but with any unacceptable 
characters removed [it only uses: A-Za-z0-9_]; if this would duplicate a 
name then an incrementing numerical suffix is added - e.g. 'Site_001.dae'.
On completion the total number of Layers exported as DAEs is reported.
Note that you can change the DAE export options in the rb_file itself - 
except for 'selectionset_only' which must always be set as 'true'.
___________________________________________________________________________
Donations:
by PayPal to info @ revitrev.org
___________________________________________________________________________
Version:
1.0 20101010 First release.
___________________________________________________________________________
=end
require 'sketchup.rb'
###
def exportlayers2daes()
  model=Sketchup.active_model
  mpath=model.path
  if not mpath or mpath==""
    UI.beep
    puts "Save this new model before exporting its groups as DAEs..."
    return nil
  end
  mpath=File.dirname(mpath)
  ents=model.entities
  entsa=ents.to_a
  ss=model.selection
  if not entsa[0]
    UI.beep
    puts "No Entities to export..."
    return nil
  end
  layers=model.layers
  lnames=[]
  names=[]
  num=0
  layers.each{|layer|lnames << layer.name if layer.visible?}
  lnames.each{|lname|
    ss.clear
    matches=[]
    entsa.each{|e|matches << e if e.layer.name==lname}
    next if not matches[0]
    num+=1
    ss.add(matches)
    name=("Layer_"+lname).gsub(/[^A-Za-z0-9_]/,"_")
    name=name+"_001" if names.include?(name)
    while names.include?(name)
      name.next!
    end
    names << name
    dae=name+".dae"
    puts path=File.join(mpath, dae).tr("\\","/")
    ### configure dae settings here...
    options={:triangulated_faces  => true,
             :doublesided_faces   => true,
             :edges               => false,
             :materials_by_layer  => false,
             :author_attribution  => false,
             :texture_maps        => true,
             :selectionset_only   => true,
             :preserve_instancing => true
            }
    model.export(path, options)
  }
  ss.clear
  UI.beep
  puts "Exported "+num.to_s+" Layers as DAEs."
end